@@ -5,8 +5,8 @@
 ;; Author: Samuel W. Flint <me@samuelwflint.com>
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 ;; URL: https://git.sr.ht/~swflint/emacs-universal-sidecar
-;; Package-Version: 20251021.212
-;; Package-Revision: 535cd1cd1c42
+;; Package-Version: 20251029.1934
+;; Package-Revision: 01b12aecca0c
 ;; Package-Requires: ((emacs "26.1") (magit-section "3.0.0"))
 
 ;; This file is NOT part of GNU Emacs.
@@ -365,7 +365,7 @@ add (universal-sidecar-ignore-buffer . t) to
   "Should BUFFER be ignored?
 
 This is determined by the buffer-local value of
-`universal-sidecar-ignore-buffer' being non-nil."
+variable `universal-sidecar-ignore-buffer' being non-nil."
   (buffer-local-value 'universal-sidecar-ignore-buffer buffer))
 
 
@@ -441,6 +441,20 @@ If FRAME is nil, use `selected-frame'."
                                            universal-sidecar-buffer-id-formatters))))
     (propertize (format-spec universal-sidecar-buffer-id-format specifiers) 'face 'mode-line-buffer-id)))
 
+(defun universal-sidecar--buffer-or-ignore (buffer sidecar)
+  "Return BUFFER if it is not ignored.
+
+A BUFFER is ignored if one of the following hold:
+ - BUFFER is `equal' to SIDECAR
+ - The minibuffer depth is greater than 0
+ - BUFFER name matches `universal-sidecar-ignore-buffer-regep'
+ - Any of the `universal-sidecar-ignore-buffer-functions' return true for BUFFER."
+  (unless (or (equal buffer sidecar)
+              (> (minibuffer-depth) 0)
+              (string-match-p universal-sidecar-ignore-buffer-regexp (buffer-name buffer))
+              (run-hook-with-args-until-success 'universal-sidecar-ignore-buffer-functions buffer))
+    buffer))
+
 (defun universal-sidecar-refresh (&optional buffer sidecar)
   "Refresh sections for BUFFER in SIDECAR.
 
@@ -448,40 +462,32 @@ If BUFFER is non-nil, use the currently focused buffer.
 If SIDECAR is non-nil, use sidecar for the current frame."
   (interactive)
   (save-mark-and-excursion
-    (when (universal-sidecar-visible-p)
-      (let* ((sidecar (or sidecar
-                          (universal-sidecar-get-buffer)))
-             (buffer (or buffer
-                         (if-let ((buf (window-buffer (selected-window)))
-                                  (buffer-is-ignored-p
-                                   (or (> (minibuffer-depth) 0)
-                                       (equal buf sidecar)
-                                       (string-match-p universal-sidecar-ignore-buffer-regexp
-                                                       (buffer-name buf))
-                                       (run-hook-with-args-until-success 'universal-sidecar-ignore-buffer-functions
-                                                                         buf))))
-                             (with-current-buffer sidecar universal-sidecar-current-buffer)
-                           buf))))
-        (with-current-buffer sidecar
-          (let ((inhibit-read-only t))
-            (universal-sidecar-buffer-mode)
-            (erase-buffer)
-            (setq-local mode-line-buffer-identification (universal-sidecar-format-buffer-id buffer))
-            (setq-local universal-sidecar-current-buffer buffer)
-            (universal-sidecar-set-title (propertize (buffer-name buffer) 'face 'bold) sidecar)
-            (dolist (section universal-sidecar-sections)
-              (condition-case-unless-debug err
-                  (pcase section
-                    ((pred functionp)
-                     (funcall section buffer sidecar))
-                    (`(,section . ,args)
-                     (apply section (append (list buffer sidecar) args)))
-                    (_
-                     (user-error "Invalid section definition `%S' in `universal-sidecar-sections'" section)))
-                (t
-                 (unless universal-sidecar-inhibit-section-error-log
-                   (display-warning 'universal-sidecar (format "Error encountered in displaying section %S: %S" section err) :error)))))
-            (goto-char 0)))))))
+    (when-let* ((sidecar-visible-p (universal-sidecar-visible-p))
+                (sidecar (or sidecar
+                             (universal-sidecar-get-buffer)))
+                (buffer (universal-sidecar--buffer-or-ignore (or buffer
+                                                                 (window-buffer (selected-window)))
+                                                             sidecar)))
+      (with-current-buffer sidecar
+        (let ((inhibit-read-only t))
+          (universal-sidecar-buffer-mode)
+          (erase-buffer)
+          (setq-local mode-line-buffer-identification (universal-sidecar-format-buffer-id buffer))
+          (setq-local universal-sidecar-current-buffer buffer)
+          (universal-sidecar-set-title (propertize (buffer-name buffer) 'face 'bold) sidecar)
+          (dolist (section universal-sidecar-sections)
+            (condition-case-unless-debug err
+                (pcase section
+                  ((pred functionp)
+                   (funcall section buffer sidecar))
+                  (`(,section . ,args)
+                   (apply section (append (list buffer sidecar) args)))
+                  (_
+                   (user-error "Invalid section definition `%S' in `universal-sidecar-sections'" section)))
+              (t
+               (unless universal-sidecar-inhibit-section-error-log
+                 (display-warning 'universal-sidecar (format "Error encountered in displaying section %S: %S" section err) :error)))))
+          (goto-char 0))))))
 
 ;;; Updating the Sidecar
 
@@ -508,7 +514,7 @@ If SIDECAR is non-nil, use sidecar for the current frame."
 (defun universal-sidecar-advise-commands (&optional commands-list)
   "Automatically advise COMMANDS-LIST to update the sidecar buffer.
 
-If COMMANDS-LIST is nil, `universal-sidecar-advise-commands' will
+If COMMANDS-LIST is nil, variable `universal-sidecar-advise-commands' will
 be used (which, see for format of COMMANDS-LIST)."
   (dolist (command-spec (or commands-list universal-sidecar-advise-commands))
     (pcase command-spec
@@ -526,7 +532,7 @@ be used (which, see for format of COMMANDS-LIST)."
 (defun universal-sidecar-unadvise-commands (&optional commands-list)
   "Unadvise COMMANDS-LIST to no longer update the sidecar buffer.
 
-If COMMANDS-LIST is nil, `universal-sidecar-advise-commands' will
+If COMMANDS-LIST is nil, variable `universal-sidecar-advise-commands' will
 be used (which, see for format of COMMANDS-LIST)."
   (dolist (command-spec (or commands-list universal-sidecar-advise-commands))
     (let ((command (or (and (listp command-spec) (car command-spec))
